@@ -7,6 +7,7 @@ from configparser import ConfigParser
 from subprocess import *
 import matplotlib.pyplot as plt
 
+
 current_video = ""
 frames_in = []
 current_frame_number = 0
@@ -33,6 +34,7 @@ def reset():
 
 # Retrieves behavior names from the config file
 def configure(file_name):
+    global columns
     config = ConfigParser()
     config.read(file_name)
     number_of_targets = config.get('SML settings', 'No_targets')
@@ -178,7 +180,6 @@ class MainInterface:
         if self.rangeOn.get():
             s = int(self.firstFrame.get())
             e = int(self.lastFrame.get())
-            print(s, e)
             save_values(s, e)
             if e < len(frames_in) - 1:
                 load_frame(e + 1, master, self.fbox)
@@ -250,6 +251,8 @@ class MainInterface2:
                                              '\n Ctrl + o = First frame')
         key_presses.grid(sticky=S)
         self.bind_keys()
+
+
     def Rfbox(self):
         return self.fbox
 
@@ -274,7 +277,6 @@ def play_video():
     main_project_dir = str(os.path.split(os.path.dirname(os.path.dirname(os.getcwd())))[-2])
     video_dir = main_project_dir + '\\videos\\'
     video_list = os.listdir(video_dir)
-    # current_video_name = os.path.basename(os.getcwd())
     print(video_list,video_dir)
     current_full_video_name = [i for i in video_list if current_video in i]
     try:
@@ -310,7 +312,7 @@ def choose_folder(project_name):
     os.chdir(img_dir)
     dirpath = os.path.basename(os.getcwd())
     current_video = dirpath
-    print('Current Video: ' + current_video)
+    print('Loading video ' + current_video + '...')
 
     global frames_in
     frames_in = []
@@ -446,15 +448,22 @@ def set_values(dictionary):
 
 # Saves the values of each behavior in the DataFrame and prints out the updated data frame
 def save_values(start, end):
+    global columns
+    contprintLoop = True
+    print('\n')
     if start == end:
         for i in range(len(behaviors)):
             df.at[current_frame_number, columns[i]] = int(behaviors[i])
+            if behaviors[i] != 0:
+                print('Annotated behavior: ' + columns[i] + '. Frame: ' + str(start) + '.')
+
     if start != end:
         for i in range(start, end+1):
             for b in range(len(behaviors)):
                 df.at[i, columns[b]] = int(behaviors[b])
-    #print(df.ix[current_frame_number])
-
+                if behaviors[b] != 0 and (contprintLoop == True):
+                    print('Annotated behavior: ' + columns[b] + '. Start frame: ' + str(start) + '. End frame: ' + str(end))
+            contprintLoop = False
 
 # Appends data to corresponding features_extracted csv and exports as new csv
 def save_video(master):
